@@ -22,9 +22,6 @@
 
 #include "filestorage.h"
 #include "memorycalendar.h"
-#include "utils.h"
-
-#include <QTimeZone>
 
 #include <QDebug>
 #include <QFile>
@@ -33,7 +30,7 @@
 #include <QCommandLineParser>
 #include <QTimeZone>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 
 static QString dumpTime(const QDateTime &dt, const QTimeZone &viewZone);
 
@@ -42,9 +39,14 @@ int main(int argc, char **argv)
     qputenv("TZ", "GMT");
 
     QCommandLineParser parser;
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"), QStringLiteral("Verbose output")));
-    parser.addPositionalArgument(QStringLiteral("input"), QStringLiteral("Name of input file"));
-    parser.addPositionalArgument(QStringLiteral("output"), QStringLiteral("optional name of output file for the recurrence dates"));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"),
+                                        QStringLiteral("Verbose output")));
+
+    parser.addPositionalArgument(QStringLiteral("input"),
+                                 QStringLiteral("Name of input file"));
+
+    parser.addPositionalArgument(QStringLiteral("output"),
+                                 QStringLiteral("optional name of output file for the recurrence dates"));
 
     QCoreApplication app(argc, argv);
     QCoreApplication::setApplicationName(QStringLiteral("testrecurrencenew"));
